#' "Co-citation analysis" and "Coupling analysis" manuscripts.
#'
#' Manuscripts about the topics "co-citation analysis" and 
#' "coupling analysis" published on Scientometrics Journal.\cr
#' Period: 1985 - 2015\cr
#' Database: \href{http://www.webofknowledge.com}{ISI Web of Knowledge}\cr
#'
#' @format A large character with 12731 rows.\cr 
#' Data has been imported by an ISI Export file in plain text format using the function \code{\link{readLines}}.
#' 
#' @source \url{http://www.webofknowledge.com}
#' @name scientometrics_text
NULL